@@ -61,6 +61,12 @@ class PipelineOperator:
         for kw in ['BlobEndpoint', 'QueueEndpoint', 'TableEndPoint', 'FileEndPoint', 'SharedAccessSignature', 'sv']:
             if kw not in conn_str:
                 token = ""
+                try:
+                    storage_url_container = storage_url[storage_url.rindex('.net/'):]
+                    storage_url = storage_url[0:storage_url.index(storage_url_container)] + ".net"
+                    self.logger.info(f"Removed {storage_url_container} from {storage_url} when recreating connection string")
+                except Exception as e:
+                    self.logger.info(f"Could not find blob container name in storage url, this is likely normal \n{e}")
                 if 'sv=' in conn_str:
                     token = conn_str[conn_str.index('sv='):]
                 conn_str = f"BlobEndPoint={storage_url};QueueEndPoint={storage_url.replace('.blob.', '.queue.')};FileEndPoint={storage_url.replace('.blob.', '.file.')};TableEndPoint={storage_url.replace('.blob.', '.table.')};SharedAccessSignature="
