@@ -417,12 +417,13 @@ class MapReporter:
         [content_headers, content_info] = self._map_branches(
             self.STORAGE_MAP, self.DEPTH)
         csv_data += f"\n{content_headers}\n{content_info}"
+        self.logger.info("Successfully created csv")
         return csv_data
 
     def write_csv_local(self):
         self.logger.info(f"Writing csv to {self.OUTPUT_FILE_NAME}")
         csv_data = self.create_csv()
         file = open(self.OUTPUT_FILE_NAME, "w")
-        file.write(file.write(csv_data))
+        file.write(csv_data)
         file.close()
         self.logger.info(f"Finished writing at {os.path.abspath(self.OUTPUT_FILE_NAME)}")
